@@ -3,7 +3,7 @@ from danmu_utils.common.IConverter import IConverter
 from danmu_utils.plugin.bilibili.BilibiliGenerator import  BilibiliGenerator
 
 
-class DiyidanToBilibiliConverter(IConverter):
+class MgtvToBilibiliConverter(IConverter):
     @property
     def DANMU_TYPE_SRC(self):
         return 'mgtv'
@@ -42,4 +42,4 @@ class DiyidanToBilibiliConverter(IConverter):
 
 from danmu_utils.common.plugin_collection import add_convert_tool
 
-add_convert_tool(DiyidanToBilibiliConverter().DANMU_TYPE_SRC, DiyidanToBilibiliConverter().DANMU_TYPE_DST, DiyidanToBilibiliConverter)
+add_convert_tool(MgtvToBilibiliConverter().DANMU_TYPE_SRC, MgtvToBilibiliConverter().DANMU_TYPE_DST, MgtvToBilibiliConverter)
